/* A demonstration of the SAS macro SEM */
/* Feb 18, 2009 by Li Cai */

/* The correct way of citing the macro is:
   Cai, L., & Lee, T. (in press). Covariance structure model fit testing under
        missing data: An application of the Supplemented EM algorithm. 
        Multivariate Behavioral Research. */

/* Include the Supplemented EM macro.
   The path shown below should be replaced with the path on your computer 
   where the SEM macro is located. */
%include 'D:\myfolder\SEM.sas';

/* File names:
   The paths shown below should be replaced with the paths on your computer */
filename srcdfile 'D:\myfolder\srcd.dat';
filename mardiaf 'D:\myfolder\mardia.dat';

/* Load SRCD data.
   For detailed information, please refer to Cai & Lee's paper or this webpage:
   http://www.unc.edu/~curran/example.htm   */
data srcd; infile srcdfile;
  input anti1-anti4 read1-read4 gen momage kidage homecog homeemo id;
run;

/* A conditional latent curve model */
%let mymodel=%str(
  lineqs
    anti1 = 1f1 + 0f2 + e1,
    anti2 = 1f1 + 1f2 + e2,
    anti3 = 1f1 + 2f2 + e3,
    anti4 = 1f1 + 3f2 + e4,	
    f1 = al1 intercept + gamma1 gen + gamma2 momage + d1,
    f2 = al2 intercept + gamma3 gen + gamma4 momage + d2,
    gen = al3 intercept + d3,
    momage = al4 intercept + d4;
  std
    e1-e4 = th1 th2 th3 th4,
    d1-d4 = ph11 ph22 ph33 ph44;		
  cov
    d1 d2 = ph12,	 
    d3 d4 = ph34;
);
%SEM(indata=srcd,var=anti1 anti2 anti3 anti4 gen momage,
     nvar=6,nobs=405,calismodel=&mymodel);

/* Load Open-book Close-book data.
   For detailed information, please refer to Cai & Lee's paper.  */
data mardia; infile mardiaf;
  input y1-y5;
run;

/* define a confirmatory factor analysis model */
%let calismodel=%str(
  lineqs
    y1 = a1 intercept + l11 f1 +   0 f2 + e1,
    y2 = a2 intercept + l21 f1 +   0 f2 + e2,
    y3 = a3 intercept +   0 f1 + l32 f2 + e3,
    y4 = a4 intercept +   0 f1 + l42 f2 + e4,
    y5 = a5 intercept +   0 f1 + l52 f2 + e5;
  std
    e1-e5 = th1 th2 th3 th4 th5,
    f1 f2 = 1 1;
  cov
    f1 f2 = ph21;
);
%SEM(indata=mardia,var=y1 y2 y3 y4 y5,
     nvar=5,nobs=88,calismodel=&calismodel);
